@@ -22,6 +22,8 @@ using System;
 using Gtk;
 using Mono.Unix;
 using LongoMatch.Video.Editor;
+using LongoMatch.Video.Common;
+using LongoMatch.Common;
 
 namespace LongoMatch.Gui.Dialog
 {
@@ -32,25 +34,21 @@ namespace LongoMatch.Gui.Dialog
 	{
 		private VideoQuality vq;
 		private VideoFormat vf;
-		private VideoCodec vcodec;
-		private AudioCodec acodec;
-		private VideoMuxer muxer;
-
-		private const string MP4="MP4 (H.264+AAC)";
-		private const string AVI="AVI (Xvid+MP3)";
-		private const string OGG="OGG (Theora+Vorbis)";
-		private const string DVD="DVD (MPEG-2)";
+		private VideoEncoderType vcodec;
+		private AudioEncoderType acodec;
+		private VideoMuxerType muxer;
 
 
 		#region Constructors
 		public VideoEditionProperties()
 		{
 			this.Build();
-			formatcombobox.AppendText(MP4);
-			formatcombobox.AppendText(AVI);
+			formatcombobox.AppendText(Constants.MP4);
+			formatcombobox.AppendText(Constants.AVI);
 			if (System.Environment.OSVersion.Platform != PlatformID.Win32NT) {
-				formatcombobox.AppendText(OGG);
-				formatcombobox.AppendText(DVD);
+				formatcombobox.AppendText(Constants.WEBM);
+				formatcombobox.AppendText(Constants.OGG);
+				formatcombobox.AppendText(Constants.DVD);
 			}
 			formatcombobox.Active=0;
 		}
@@ -64,19 +62,19 @@ namespace LongoMatch.Gui.Dialog
 			}
 		}
 
-		public VideoCodec VideoCodec {
+		public VideoEncoderType VideoEncoderType {
 			get {
 				return vcodec;
 			}
 		}
 
-		public AudioCodec AudioCodec {
+		public AudioEncoderType AudioEncoderType {
 			get {
 				return acodec;
 			}
 		}
 
-		public VideoMuxer VideoMuxer {
+		public VideoMuxerType VideoMuxer {
 			get {
 				return muxer;
 			}
@@ -110,11 +108,13 @@ namespace LongoMatch.Gui.Dialog
 		#region Private Methods
 
 		private string GetExtension() {
-			if (formatcombobox.ActiveText == MP4)
-				return "mkv";
-			else if (formatcombobox.ActiveText == OGG)
+			if (formatcombobox.ActiveText == Constants.MP4)
+				return "mp4";
+			else if (formatcombobox.ActiveText == Constants.OGG)
 				return "ogg";
-			else if (formatcombobox.ActiveText == AVI)
+			else if (formatcombobox.ActiveText == Constants.WEBM)
+				return "webm";
+			else if (formatcombobox.ActiveText == Constants.AVI)
 				return "avi";
 			else
 				return "mpg";
@@ -139,25 +139,30 @@ namespace LongoMatch.Gui.Dialog
 
 			vf = (VideoFormat)sizecombobox.Active;
 
-			if (formatcombobox.ActiveText == MP4) {
-				vcodec = VideoCodec.H264;
-				acodec = AudioCodec.AAC;
-				muxer = VideoMuxer.MKV;
+			if (formatcombobox.ActiveText == Constants.MP4) {
+				vcodec = VideoEncoderType.H264;
+				acodec = AudioEncoderType.Aac;
+				muxer = VideoMuxerType.Matroska;
 			}
-			else if (formatcombobox.ActiveText == OGG) {
-				vcodec = VideoCodec.THEORA;
-				acodec = AudioCodec.VORBIS;
-				muxer = VideoMuxer.OGG;
+			else if (formatcombobox.ActiveText == Constants.OGG) {
+				vcodec = VideoEncoderType.Theora;
+				acodec = AudioEncoderType.Vorbis;
+				muxer = VideoMuxerType.Ogg;
 			}
-			else if (formatcombobox.ActiveText == AVI) {
-				vcodec = VideoCodec.XVID;
-				acodec = AudioCodec.MP3;
-				muxer = VideoMuxer.AVI;
+			else if (formatcombobox.ActiveText == Constants.WEBM) {
+				vcodec = VideoEncoderType.VP8;
+				acodec = AudioEncoderType.Vorbis;
+				muxer = VideoMuxerType.WebM;
 			}
-			else if (formatcombobox.ActiveText == DVD) {
-				vcodec = VideoCodec.MPEG2_VIDEO;
-				acodec = AudioCodec.MPEG2_AUDIO;
-				muxer = VideoMuxer.DVD;
+			else if (formatcombobox.ActiveText == Constants.AVI) {
+				vcodec = VideoEncoderType.Xvid;
+				acodec = AudioEncoderType.Mp3;
+				muxer = VideoMuxerType.Avi;
+			}
+			else if (formatcombobox.ActiveText == Constants.DVD) {
+				vcodec = VideoEncoderType.Mpeg2;
+				acodec = AudioEncoderType.Mp3;
+				muxer = VideoMuxerType.MpegPS;
 			}
 			Hide();
 		}
@@ -175,6 +180,7 @@ namespace LongoMatch.Gui.Dialog
 			FileFilter filter = new FileFilter();
 			filter.Name = "Multimedia Files";
 			filter.AddPattern("*.mkv");
+			filter.AddPattern("*.mp4");
 			filter.AddPattern("*.ogg");
 			filter.AddPattern("*.avi");
 			filter.AddPattern("*.mpg");
@@ -185,5 +191,11 @@ namespace LongoMatch.Gui.Dialog
 			}
 			fChooser.Destroy();
 		}
+		protected virtual void OnButtonCancelClicked (object sender, System.EventArgs e)
+		{
+			this.Destroy();
+		}
+		
+		
 	}
 }
